@@ -33,6 +33,9 @@ class cmnConfig:
         self.config_ini = None
         """ iniファイル読込内容 """
 
+        self.scriptFilePath = ''
+        """ スクリプトファイルパス """
+
     def getConfigFileName(self):
         
         """ 
@@ -48,7 +51,7 @@ class cmnConfig:
         """
         return 'LibHanger.ini'
     
-    def getConfig(self, scriptPath: str, configFileDir: str = ''):
+    def getConfig(self, _scriptFilePath: str, configFileDir: str = ''):
 
         """ 
         設定ファイルを読み込む 
@@ -67,11 +70,14 @@ class cmnConfig:
         # configparser宣言
         config_ini = configparser.ConfigParser()
 
+        # スクリプトファイルパスをセット
+        self.scriptFilePath = _scriptFilePath
+        
         # スクリプトファイルの場所から見たiniファイル相対パス取得
         iniFileDirPath = self.getConfigFileName() \
             if configFileDir == '' else os.path.join(configFileDir, self.getConfigFileName())
         # スクリプトファイルの絶対パス取得
-        iniScriptPathAbs = pathlib.Path(os.path.abspath(os.path.dirname(scriptPath)))
+        iniScriptPathAbs = pathlib.Path(os.path.abspath(os.path.dirname(_scriptFilePath)))
         # iniファイルパス取得
         iniFilePath = os.path.join(iniScriptPathAbs, iniFileDirPath)
 
@@ -100,9 +106,7 @@ class cmnConfig:
         
         Parameters
         ----------
-        config_ini : list
-            iniファイル読込内容List
-        
+        None
         """
         
         self.setConfigValue('LogFileName', self.config_ini,'DEFAULT','LOGFILE_NAME', str)
